
# Type: genotype to genotype part association_relation




URI: [biolink:genotype_to_genotype_part_association_relation](https://w3id.org/biolink/vocab/genotype_to_genotype_part_association_relation)


## Domain and Range

[GenotypeToGenotypePartAssociation](GenotypeToGenotypePartAssociation.md) ->  <sub>REQ</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents

 *  is_a: [relation](relation.md)

## Children


## Used by

 * [GenotypeToGenotypePartAssociation](GenotypeToGenotypePartAssociation.md)
